#
# spec file for package spice-protocol
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spice-protocol
Version:        0.14.4
Release:        2.2
Summary:        SPICE-protocol definitions
License:        BSD-3-Clause
Group:          Development/Languages/C and C++
URL:            https://www.spice-space.org/
Source:         https://www.spice-space.org/download/releases/spice-protocol-%{version}.tar.xz
Source1:        https://www.spice-space.org/download/releases/spice-protocol-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  meson >= 0.41.0
BuildRequires:  pkgconfig
Requires:       python-pyparsing
Requires:       python-six
BuildArch:      noarch

%description
Headers defining the SPICE-protocol

%package devel
Summary:        SPICE-protocol definitions
Group:          Development/Languages/C and C++

%description devel
Headers defining the SPICE-protocol

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
# drop the libdir= entry from the .pc file. It's irrelevant for a arch-independent file
sed -i "/libdir=/d" %{buildroot}%{_datadir}/pkgconfig/spice-protocol.pc

%files devel
%license COPYING
%doc CHANGELOG.md README.md
%{_datadir}/pkgconfig/spice-protocol.pc
%{_includedir}/spice-1/

%changelog
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Fri Feb 11 2022 carnold@suse.com
- Update to version 0.14.4
  * Fix enum deprecation warning for visual studio
  * Fix documentation typos in stream-device.h
* Mon Oct  5 2020 Bruce Rogers <brogers@suse.com>
- Update to version 0.14.3
  + Add VD_AGENT_CLIPBOARD_FILE_LIST to support copy/paste of files with
  WebDAV support
  + Add support for side mouse buttons
  + Add a MonitorsMM field to VDAgentMonitorsConfig allowing to pass
  physical monitor dimension
* Wed Sep 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libdir=/usr/(lib|lib64} entry from the .pc file: the
  package is noarch and the libdir entry changes between archs
  (boo#1109895).
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.14.2:
  * Removed Autoconf support, only Meson is available
  * Removed foreign-menu and controller interfaces
  * Deprecated CELT support
  * Generate MingW packages building the RPM
  * Allows for the agent to pass back a more specific error to the client
  * Add quality indicators messages
* Mon Mar  9 2020 Bruce Rogers <brogers@suse.com>
- Update to version 0.14.1
  + Introduce VD_AGENT_CAP_CLIPBOARD_GRAB_SERIAL
  + Introduce VD_AGENT_CAP_CLIPBOARD_NO_RELEASE_ON_REGRAB
  + Deprecate foreign-menui_prot.h and controller_prot.h interfaces
  + Remove VD_AGENT_CLIPBOARD_MAX_SIZE_[DEFAULT ENV]
  + Define Quality Indicator messages and enums
  + Fix alignment for QXLReleaseInfo
  + Other misc fixes
* Tue Apr 16 2019 Bruce Rogers <brogers@suse.com>
- Update to version 0.14.0:
  + Add: VDAgentGraphicsDeviceInfo and StreamMsgGraphicsDeviceInfo
    messages, and SpiceStat structure padding
  + Remove: SpicePubkeyType, SpiceTunnelServiceType,
    SpiceTunnelIpType, SPICE_MSG_TUNNEL_* and SPICE_MSGC_TUNNEL_*
- Add keyring and tarball signature files
* Thu Feb 28 2019 olaf@aepfle.de
- Require meson >= 0.41.0 per meson.build
- Use autosetup -p1, in case we require patches in the future
* Sat Jan 19 2019 Bruce Rogers <brogers@suse.com>
- Update to version 0.12.15:
  + add support for h265 video codec
* Tue Jun 19 2018 luc14n0@linuxmail.org
- Update to version 0.12.14:
  + Add: stream-device protocol; SPICE_SURFACE_FLAGS_STREAMING_MODE
    flag; e2k (Elbrus 2000) architecture and SPICE_MAX_NUM_STREAMS.
- Replace autoconf and automake BuildRequires with meson, and
  configure/make (install) with meson/meson_build/meson_install
  macros to follow upstream changes.
* Mon Aug 28 2017 cbosdonnat@suse.com
- Update to version 0.12.13:
  + add DISPLAY_PREFERRED_VIDEO_CODEC_TYPE
  + add VP9 codec type
  + add VD_AGENT_CLEAR_CAPABILITY() macro
  + add VD_AGENT_CAP_FILE_XFER_DISABLED
  + add VD_AGENT_FILE_XFER_STATUS_NOT_ENOUGH_SPACE
  + add new file-xfer statuses for detailed error
  + Change enums.h license to MIT
* Mon Oct 17 2016 stefan.bruens@rwth-aachen.de
- Update to version 0.12.12 (fate#322402):
  + protocol: Add lz4 compression support to the SpiceVMC channel
* Tue Apr 26 2016 olaf@aepfle.de
- Fix autoreconf by creating empty m4 directory
* Fri Mar 18 2016 dimstar@opensuse.org
- Update to version 0.12.11:
  + protocol: add support for the VP8 and h264 video codecs.
  + protocol: add unix GL scanout messages.
  + Remove code generation scripts, moved back to spice-common.
  + Macros improvements, more type safety.
- Drop
  0001-build-sys-Use-datadir-for-.proto-files-codegen-scrip.patch:
  No longer needed, as the code generation scripts live in
  spice-common again.
- fate#320079
* Tue Oct  6 2015 cbosdonnat@suse.com
- Update to version 0.12.10:
  + Add VD_AGENT_CAP_MONITORS_CONFIG_POSITION to handle multi-monitor
  configurations that are not multi-head
  + Add protocol code generation scripts from spice-common
  + Endianness and compiler portability fixes (clang)
- Fix the release to output arch independent files in datadir
  rather than libdir:
  0001-build-sys-Use-datadir-for-.proto-files-codegen-scrip.patch
* Sun Aug  2 2015 mpluskal@suse.com
- Update to 0.12.9
  + Rename newly introduced SpiceImageCompress enum to
    SpiceImageCompression as otherwise it was clashing with the
    definition used by older spice-server releases, breaking QEMU
    build.
- Drop no longer needed patch revert-da3cf336.patch.
- Tiny spec file cleanup:
  + drop empty documentation files.
  + do not use obsoleyr makeinstall macro.
* Wed Jul 22 2015 cbosdonnat@suse.com
- Fix incompatibility with spice-server headers.
  revert-da3cf336.patch
* Mon Jul 20 2015 zaitor@opensuse.org
- Update to version 0.12.8:
  + Add LZ4 support.
  + Add audio volume synchronization.
  + Deprecate unused vdi-dev.
  + Add 'preferred-compression' message/capability.
  + Add a new Windows driver escape code to send monitors
    capability from guest to client.
* Wed Oct 15 2014 zaitor@opensuse.org
- Update to version 0.12.7:
  + Add support for Webdav channel.
  + Add support for the Opus codec.
* Sun Jun 30 2013 zaitor@opensuse.org
- Update to version 0.12.6:
  + Add adaptive video streaming support: control playback latency
    and receive playback reports from the client.
  + Add agent capabilities for signaling guest line ending.
* Fri Apr  5 2013 dimstar@opensuse.org
- Update to version 0.12.5:
  + Add agent file xfer success status.
  + Add a client-disconnected agent message.
- Changes from version 0.12.4:
  + Add agent file copy support.
  + Add agent sparse monitors capability.
  + Add controller proxy message.
* Sat Jan 19 2013 zaitor@opensuse.org
- Update to version 0.12.3:
  + Add a generic "port" channel.
* Tue Sep 18 2012 sndirsch@suse.com
- Update to version 0.12.2
  + display channel: A8 surface capability
  + qxl: client present, client capabilities and client monitors
    configuration.
* Sat Jul 28 2012 dimstar@opensuse.org
- Update to version 0.12.0:
  + Add support for arbitrary resolution on Windows QXL with
    QXL_ESCAPE_SET_CUSTOM_DISPLAY
  + Add support for arbitrary resolution and multiple monitor per
    display channel with QXLMonitorsConfig and co
  + build cleanup
* Sat May 26 2012 reddwarf@opensuse.org
- Update to version 0.10.3:
  + Add support for video streams with differently sized (wxh) data
  + Add controller messages for USB redirection, COLOR_DEPTH, DISABLE_EFFECTS,
    and ENABLE_SMARTCARD
  + Add name & uuid messages on main channel
  + some cleanups
  + Fixes RHBZ#815422, RHBZ#807295, RHBZ#787447
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 0.10.1:
  + Add support for a header without sublist and serial.
* Tue Nov 29 2011 dimstar@opensuse.org
- Initial package, prepared for inclusion in Factory.
